@@ -805,11 +805,11 @@ impl<K, V, KH, C, U, CB, S> Cache<K, V, KH, C, U, CB, S>
 
         match self.store.get(&index, conflict) {
             None => {
-                self.metrics.add(MetricType::Hit, index, 1);
+                self.metrics.add(MetricType::Miss, index, 1);
                 None
             }
             Some(v) => {
-                self.metrics.add(MetricType::Miss, index, 1);
+                self.metrics.add(MetricType::Hit, index, 1);
                 Some(v)
             }
         }
@@ -825,11 +825,11 @@ impl<K, V, KH, C, U, CB, S> Cache<K, V, KH, C, U, CB, S>
         let (index, conflict) = self.key_to_hash.build_key(key);
         match self.store.get_mut(&index, conflict) {
             None => {
-                self.metrics.add(MetricType::Hit, index, 1);
+                self.metrics.add(MetricType::Miss, index, 1);
                 None
             }
             Some(v) => {
-                self.metrics.add(MetricType::Miss, index, 1);
+                self.metrics.add(MetricType::Hit, index, 1);
                 Some(v)
             }
         }
@@ -878,6 +878,12 @@ impl<K, V, KH, C, U, CB, S> Cache<K, V, KH, C, U, CB, S>
         self.policy.update_max_cost(max_cost)
     }
 
+    /// Returns the number of items in the Cache
+    #[inline]
+    pub fn len(&self) -> usize {
+        self.store.len()
+    }
+
     cfg_async! {
         /// `insert` attempts to add the key-value item to the cache. If it returns false,
         /// then the `insert` was dropped and the key-value item isn't added to the cache. If
