@@ -1,8 +1,5 @@
 use crate::cache::{Cache, Item};
-use crate::{
-    CacheCallback, Coster, DefaultKeyBuilder, Item as CrateItem, KeyBuilder, TransparentKeyBuilder,
-    UpdateValidator,
-};
+use crate::{CacheCallback, Coster, DefaultKeyBuilder, Item as CrateItem, KeyBuilder, TransparentKeyBuilder, UpdateValidator, CacheBuilder, DefaultCoster, DefaultUpdateValidator, DefaultCacheCallback};
 use parking_lot::Mutex;
 use rand::rngs::OsRng;
 use rand::Rng;
@@ -11,6 +8,7 @@ use std::hash::Hash;
 use std::sync::atomic::{AtomicU64, Ordering};
 use std::sync::Arc;
 use std::time::Duration;
+use std::collections::hash_map::RandomState;
 
 static CHARSET: &'static [u8] = "abcdefghijklmnopqrstuvwxyz0123456789".as_bytes();
 
@@ -128,6 +126,22 @@ cfg_not_async! {
         }
     }
 
+    #[test]
+    fn test_cache_builder() {
+        let _: Cache<u64, u64, DefaultKeyBuilder> = CacheBuilder::new(100, 10, TransparentKeyBuilder::default())
+        .set_coster(DefaultCoster::default())
+        .set_update_validator(DefaultUpdateValidator::default())
+        .set_callback(DefaultCacheCallback::default())
+        .set_num_counters(200)
+        .set_max_cost(100)
+        .set_cleanup_duration(Duration::from_secs(1))
+        .set_buffer_size(1000)
+        .set_key_builder(DefaultKeyBuilder::default())
+        .set_hasher(RandomState::default())
+        .finalize()
+        .unwrap();
+    }
+
     #[test]
     fn test_cache_key_to_hash() {
         let ctr = Arc::new(AtomicU64::new(0));
@@ -703,6 +717,22 @@ cfg_async! {
         }
     }
 
+    #[tokio::test]
+    async fn test_cache_builder() {
+        let _: Cache<u64, u64, DefaultKeyBuilder> = CacheBuilder::new(100, 10, TransparentKeyBuilder::default())
+        .set_coster(DefaultCoster::default())
+        .set_update_validator(DefaultUpdateValidator::default())
+        .set_callback(DefaultCacheCallback::default())
+        .set_num_counters(200)
+        .set_max_cost(100)
+        .set_cleanup_duration(Duration::from_secs(1))
+        .set_buffer_size(1000)
+        .set_key_builder(DefaultKeyBuilder::default())
+        .set_hasher(RandomState::default())
+        .finalize()
+        .unwrap();
+    }
+
     #[tokio::test]
     async fn test_cache_key_to_hash() {
         let ctr = Arc::new(AtomicU64::new(0));
@@ -1263,4 +1293,4 @@ cfg_async! {
             assert!(c.get(&i).is_none());
         })
     }
-}
+}
\ No newline at end of file
