@@ -195,6 +195,10 @@ impl<
         }
     }
 
+    pub fn len(&self) -> usize {
+        self.shards.iter().map(|l| l.read().len()).sum()
+    }
+
     pub fn remove(&self, key: &u64, conflict: u64) -> Option<StoreItem<V>> {
         let mut data = self.shards[(*key as usize) % NUM_OF_SHARDS].write();
 
